@@ -11,7 +11,7 @@ class CreateLoggerController:
         log_format = logging.Formatter(loggingConstants.LOGFORMAT)
         self.logger.setLevel(logging.DEBUG)
         self.logger.addHandler(self.newHandler(loggingConstants.DEBUGLOG, logging.DEBUG, log_format))
-        self.logger.addHandler(self.newHandler(loggingConstants.WARNINGLOG, logging.WARNING, log_format))
+        self.logger.addHandler(self.newHandler(loggingConstants.ERRORLOG, logging.ERROR, log_format))
         self.logger.addHandler(self.newHandler(loggingConstants.INFOLOG, logging.INFO, log_format))
         """console = logging.StreamHandler(sys.stdout)
         console.setFormatter(log_format)
