@@ -118,10 +118,11 @@ def generate_zip(server_address: str = None, server_filename: str = "pubserver.p
         manifest_parent.write(man_parent)
     print(f"Generating Main Data Package: {username}_DP.zip")
     copyfile(f"./{username}.zip", f"./{parentfolder}/{username}.zip")
-    zipp = zipfile.ZipFile(pathlib.PurePath(pathlib.Path(MainConfig.clientPackages), pathlib.Path(f"{username}.zip")), 'w', zipfile.ZIP_DEFLATED)
+    zipp = zipfile.ZipFile(str(pathlib.PurePath(pathlib.Path(MainConfig.clientPackages), pathlib.Path(f"{username}.zip"))), 'w', zipfile.ZIP_DEFLATED)
     for root, dirs, files in os.walk('./' + parentfolder):
         for file in files:
-            zipp.write(os.path.join(root, file))
+            name = str(pathlib.PurePath(pathlib.Path(root), pathlib.Path(file)))
+            zipp.write(name)
     for root, dirs, files in os.walk('./MANIFEST'):
         for file in files:
             zipp.write(os.path.join(root, file))
