@@ -367,8 +367,8 @@ class FTS:
                 if FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceIP != "":
                     self.FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceIP = FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceIP
 
-
-            elif FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceStatus == 'stop':
+            elif FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceStatus == 'stop' \
+                    and self.FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceStatus != 'stop':
                 self.FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceStatus = FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceStatus
                 self.stop_federation_server_service()
 
@@ -577,7 +577,7 @@ class FTS:
 
                 StartupObject.FederationClientService.FederationClientServiceStatus = 'start'
 
-                StartupObject.FederationServerService.FederationServerServiceStatus = 'start'
+                #StartupObject.FederationServerService.FederationServerServiceStatus = ''
 
                 StartupObject.SSLCoTService.SSLCoTServiceStatus = 'start'
                 StartupObject.SSLCoTService.SSLCoTServiceIP = SSLCoTIP
