@@ -1,6 +1,7 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.DescriptionVariables import DescriptionVariables as vars
 
-class Description:
+class Description(FTSProtocolObject):
     @staticmethod
     def Checklist(INTAG = vars.Checklist().INTAG):
         description = Description()
